@@ -27,14 +27,14 @@ void ContactMetaDataAkonadi::load(const Akonadi::Item &contact)
     if (!contact.hasAttribute("contactmetadata")) {
         return;
     }
-    const auto *attribute = contact.attribute<ContactMetaDataAttribute>();
+    const auto attribute = contact.attribute<ContactMetaDataAttribute>();
     const QVariantMap metaData = attribute->metaData();
     loadMetaData(metaData);
 }
 
 void ContactMetaDataAkonadi::store(Akonadi::Item &contact)
 {
-    auto *attribute = contact.attribute<ContactMetaDataAttribute>(Item::AddIfMissing);
+    auto attribute = contact.attribute<ContactMetaDataAttribute>(Item::AddIfMissing);
 
     attribute->setMetaData(storeMetaData());
 }
