@@ -18,7 +18,7 @@
 MainWidget::MainWidget()
     : QWidget(nullptr)
 {
-    auto *layout = new QGridLayout(this);
+    auto layout = new QGridLayout(this);
 
     mAddressesWidget = new Akonadi::EmailAddressSelectionWidget;
     layout->addWidget(mAddressesWidget, 0, 0);
@@ -26,13 +26,13 @@ MainWidget::MainWidget()
     mInfo = new QTextBrowser;
     layout->addWidget(mInfo, 0, 1);
 
-    auto *box = new KComboBox;
+    auto box = new KComboBox;
     box->addItem(QStringLiteral("Single Selection"));
     box->addItem(QStringLiteral("Multi Selection"));
     connect(box, QOverload<int>::of(&KComboBox::activated), this, &MainWidget::selectionModeChanged);
     layout->addWidget(box, 1, 0);
 
-    QPushButton *button = new QPushButton(QStringLiteral("Show Selection"));
+    auto button = new QPushButton(QStringLiteral("Show Selection"));
     connect(button, &QPushButton::clicked, this, &MainWidget::showSelection);
     layout->addWidget(button, 1, 1);
 }
