@@ -7,8 +7,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PHONEWIDGET_H
-#define PHONEWIDGET_H
+#pragma once
 
 #include "contacteditor_private_export.h"
 #include <QWidget>
@@ -35,9 +34,9 @@ public:
     void setPreferred(bool b);
     void setReadOnly(bool readOnly);
 Q_SIGNALS:
-    void addWidget(PhoneWidget *);
-    void removeWidget(PhoneWidget *);
-    void preferredChanged(PhoneWidget *);
+    void addWidget(ContactEditor::PhoneWidget *);
+    void removeWidget(ContactEditor::PhoneWidget *);
+    void preferredChanged(ContactEditor::PhoneWidget *);
 
 private:
     void slotAddPhone();
@@ -49,4 +48,3 @@ private:
     PhoneComboBoxType *mPhoneType = nullptr;
 };
 }
-#endif // PHONEWIDGET_H
