@@ -219,7 +219,7 @@ void ImageWidget::mouseMoveEvent(QMouseEvent *event)
 {
     if ((event->buttons() & Qt::LeftButton) && (event->pos() - mDragStartPos).manhattanLength() > QApplication::startDragDistance()) {
         if (mHasImage) {
-            auto *drag = new QDrag(this);
+            auto drag = new QDrag(this);
             drag->setMimeData(new QMimeData());
             drag->mimeData()->setImageData(mPicture.data());
             drag->exec(Qt::CopyAction);
@@ -267,14 +267,17 @@ void ImageWidget::changeUrl()
     if (mReadOnly) {
         return;
     }
-    const QString path = QInputDialog::getText(this, i18n("Change image URL"), i18n("Image URL:"), QLineEdit::Normal, mPicture.url());
-    if (!path.isEmpty()) {
-        bool ok;
-        const QImage image = imageLoader()->loadImage(QUrl(path), &ok, false);
-        if (ok && !image.isNull()) {
-            mPicture.setUrl(path);
-            mHasImage = true;
-            updateView();
+    bool okPath = false;
+    const QString path = QInputDialog::getText(this, i18n("Change image URL"), i18n("Image URL:"), QLineEdit::Normal, mPicture.url(), &okPath);
+    if (okPath) {
+        if (!path.isEmpty()) {
+            bool ok;
+            const QImage image = imageLoader()->loadImage(QUrl(path), &ok, false);
+            if (ok && !image.isNull()) {
+                mPicture.setUrl(path);
+                mHasImage = true;
+                updateView();
+            }
         }
     }
 }
